@@ -288,7 +288,7 @@ _dbus_get_peer_pid_from_tcp_handle (int handle)
       return 0;
     }
 
-  _dbus_verbose ("trying to get peers pid");
+  _dbus_verbose ("trying to get peer's pid\n");
 
   result = get_pid_from_extended_tcp_table (peer_port);
   if (result > 0)
@@ -2138,6 +2138,15 @@ _dbus_getpid (void)
   return GetCurrentProcessId ();
 }
 
+/** Gets our Unix UID
+ * @returns on Windows, just DBUS_UID_UNSET
+ */
+dbus_uid_t
+_dbus_getuid (void)
+{
+  return DBUS_UID_UNSET;
+}
+
 /** nanoseconds in a second */
 #define NANOSECONDS_PER_SECOND       1000000000
 /** microseconds in a second */
@@ -2403,7 +2412,7 @@ _dbus_delete_file (const DBusString *filename,
 #include <imagehlp.h>
 #include <stdio.h>
 
-#define DPRINTF _dbus_warn
+#define DPRINTF(fmt, ...) fprintf (stderr, fmt, ##__VA_ARGS__)
 
 #ifdef _MSC_VER
 #define BOOL int
@@ -2935,6 +2944,7 @@ _dbus_daemon_publish_session_bus_address (const char* address, const char *scope
   char *shared_addr = NULL;
   DBusString shm_name;
   DBusString mutex_name;
+  dbus_uint64_t len;
 
   _dbus_assert (address);
 
@@ -2969,7 +2979,7 @@ _dbus_daemon_publish_session_bus_address (const char* address, const char *scope
     }
 
   // create shm
-  dbus_uint64_t len = strlen( address ) + 1;
+  len = strlen (address) + 1;
 
   hDBusSharedMem = CreateFileMappingA( INVALID_HANDLE_VALUE, NULL, PAGE_READWRITE,
                                        len >> 32, len & 0xffffffffu,
@@ -3117,8 +3127,8 @@ _dbus_get_autolaunch_address (const char *scope, DBusString *address,
 
   if (_dbus_daemon_already_runs(address,&shm_name,scope))
     {
-        _dbus_verbose( "found running dbus daemon at %s\n",
-                       _dbus_string_get_const_data (&shm_name) );
+        _dbus_verbose( "found running dbus daemon for scope '%s' at %s\n",
+                       scope ? scope : "", _dbus_string_get_const_data (&shm_name) );
         retval = TRUE;
         goto out;
     }
@@ -3609,13 +3619,8 @@ _dbus_win_set_error_from_win_error (DBusError *error,
                   (LPSTR) &msg, 0, NULL);
   if (msg)
     {
-      char *msg_copy;
-
-      msg_copy = dbus_malloc (strlen (msg));
-      strcpy (msg_copy, msg);
+      dbus_set_error (error, "win32.error", "%s", msg);
       LocalFree (msg);
-
-      dbus_set_error (error, "win32.error", "%s", msg_copy);
     }
   else
     dbus_set_error (error, "win32.error", "Unknown error code %d or FormatMessage failed", code);
